/**
 * @(#) NestingTags.java  2016/04/22
 * Copyright (c) 2016 No Magic, Inc. All Rights Reserved.
 */
package org.w3c.tidy;

import org.junit.Assert;
import org.junit.Test;

import java.io.StringReader;
import java.io.StringWriter;

/**
 * @author tomluk
 */
public class NestingTags {

    @Test
    public void nestedSup()
    {
        String content = "<p>x<sup>y<sup>z</sup></sup></p>";
        String html = "<html><body>" + content + "</body></html>";

        String result = parseWithTidy(html);

        Assert.assertTrue("not matching sup test", result.contains(content));
    }

    @Test
    public void nestedSub()
    {
        String content = "<p>x<sub>y<sub>z</sub></sub></p>";
        String html = "<html><body>" + content + "</body></html>";

        String result = parseWithTidy(html);

        Assert.assertTrue("not matching sub test", result.contains(content));
    }

    @Test
    public void nestingStyleTags()
    {
        String content = "<i><b><u>first text</u>second text</b>third formatted text fourth text</i>";
        String html = "<html><body><p>" + content + "</p></body></html>";

        String result = parseWithTidy(html);

        Assert.assertTrue("not matching nested style tags test", result.replaceAll("\\r\\t\\n", " ").replaceAll("\\s+", " ").contains(content));
    }

    @Test
    public void nestingStyleTagsCleanup()
    {
        String dirtyContent = "<i><b><u>first text</u>second text</b><i>third formatted text</i>fourth text</i>";
        String dirtyHtml = "<html><body><p>" + dirtyContent + "</p></body></html>";
        String cleanedContent = "<i><b><u>first text</u>second text</b>third formatted text fourth text</i>";

        String result = parseWithTidy(dirtyHtml);

        Assert.assertTrue("not matching nested style tags test", result.replaceAll("\\r\\t\\n", " ").replaceAll("\\s+", " ").contains(cleanedContent));
    }

    private String parseWithTidy(String html)
    {
        StringReader reader = new StringReader(html);
        StringWriter writer = new StringWriter();

        Tidy tidy = new Tidy();
        tidy.parse(reader, writer);

        return writer.toString();
    }
}
